==> App-FatPackUtils-0.09.tar.gz: App-FatPackUtils-0.09/lib/App/FatPackUtils.pm <==
package App::FatPackUtils;

our $DATE = '2017-07-04'; # DATE
our $VERSION = '0.09'; # VERSION

use 5.010001;

1;
# ABSTRACT: Collection of CLI utilities related to App::FatPacker

__END__

=pod

=encoding UTF-8

=head1 NAME

App::FatPackUtils - Collection of CLI utilities related to App::FatPacker

=head1 VERSION

This document describes version 0.09 of App::FatPackUtils (from Perl distribution App-FatPackUtils), released on 2017-07-04.

=head1 DESCRIPTION

This distribution provides the following command-line utilities related to
L<App::FatPacker>:

=over

=item * L<fatpack-extract>

=item * L<fatpack-info>

=item * L<update-fatpack-snippets>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-FatPackUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-FatPackUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-FatPackUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<App::FatPacker>, L<Module::FatPack>

L<App::depak>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017, 2016, 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> App-FatPackUtils-0.10.tar.gz: App-FatPackUtils-0.10/lib/App/FatPackUtils.pm <==
package App::FatPackUtils;

our $DATE = '2017-07-04'; # DATE
our $VERSION = '0.10'; # VERSION

use 5.010001;

1;
# ABSTRACT: Collection of CLI utilities related to fatpacking

__END__

=pod

=encoding UTF-8

=head1 NAME

App::FatPackUtils - Collection of CLI utilities related to fatpacking

=head1 VERSION

This document describes version 0.10 of App::FatPackUtils (from Perl distribution App-FatPackUtils), released on 2017-07-04.

=head1 DESCRIPTION

This distribution provides the following command-line utilities related to
fatpacking:

=over

=item * L<fatpack-extract>

=item * L<fatpack-info>

=item * L<update-fatpack-snippets>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-FatPackUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-FatPackUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-FatPackUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<App::FatPacker>, L<Module::FatPack>

L<App::depak>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017, 2016, 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
